@@ -1,29 +1,3 @@
-##' Analyze and visualize differential correlations in biological networks
-##'
-##' \tabular{ll}{
-##' Package: \tab DiffCorr \cr
-##' Type: \tab Package \cr
-##' Version: \tab 0.4.1 \cr
-##' Date: \tab 2015-03-31 \cr
-##' Depends: \tab igraph, pcaMethods, fdrtool \cr
-##' License: \tab GPL (>=3) \cr
-##' LazyLoad: \tab yes \cr
-##' }
-##'
-##''
-##' @name DiffCorr
-##' @aliases DiffCorr
-##' @docType package
-##' @import fdrtool
-##' @import igraph
-##' @import multtest
-##' @import pcaMethods
-##' @title Differential correlations in omics datasets
-##' @author Atsushi Fukushima, Kozo Nishida
-NULL
-
-
-
 ##' The pre-treatment methods
 ##'
 ##' @title scalingMethods
